@@ -13,6 +13,7 @@ from ansurr import rigidipy
 from ansurr import compare
 
 from ansurr.functions import check_quiet_print
+from datetime import datetime
 
 sys.tracebacklimit = 0
 
@@ -21,13 +22,14 @@ natsort = lambda s: [int(t) if t.isdigit() else t.lower() for t in re.split('(\d
 def main():
 
     parser = argparse.ArgumentParser()
+    parser.add_argument("-p", "--pdb", type=str, help="input PDB file",required=True)
+    parser.add_argument("-s", "--shifts", type=str, help="input shifts file in NEF format",required=True)
     parser.add_argument("-l", "--lig", help=" include free ligands when computing flexibility", action="store_true")
     parser.add_argument("-n", "--nonstd", help=" include non-standard residues when computing flexibility", action="store_true")
     parser.add_argument("-o", "--olig", help="combine chains into a single structure when calculating flexibility", action="store_true")
     parser.add_argument("-q", "--quiet", help="supress output to the terminal", action="store_true")
-    parser.add_argument("-p", "--pdb", type=str, help="input PDB file",required=True)
-    parser.add_argument("-s", "--shifts", type=str, help="input shifts file in NEF format",required=True)
     parser.add_argument("-r", "--reref", help="re-reference shifts using PANAV before calculating RCI (requires Java)",action="store_true")
+    parser.add_argument("-v", "--version", action='version', version='\nANSURR | Accuracy of NMR Structures Using RCI and Rigidity v0.0.17 | citation: https://doi.org/10.1038/s41467-020-20177-1')
     args = parser.parse_args()
 
     path_to_shifts = args.shifts
@@ -36,14 +38,20 @@ def main():
     shift_file = os.path.basename(os.path.splitext(path_to_shifts)[0])
     pdb_file = os.path.basename(os.path.splitext(path_to_pdb)[0])
 
+    now = datetime.now()
+    check_quiet_print(args.quiet,"ANSURR v0.0.17 "+now.strftime("%d/%m/%Y %H:%M:%S"))
+    check_quiet_print(args.quiet," -> pdb: "+path_to_pdb)
+    check_quiet_print(args.quiet," -> shifts: "+path_to_shifts)
+
     output_dir = os.path.join(os.getcwd(), pdb_file+'_'+shift_file)
 
     if os.path.isdir(output_dir):
         shutil.rmtree(output_dir)
         check_quiet_print(args.quiet,"overwriting output directory: "+output_dir)
+    else:
+        check_quiet_print(args.quiet," -> output directory: "+output_dir)
     os.makedirs(output_dir)  
 
-
     check_quiet_print(args.quiet,"calculating RCI")
     chain_output_rci = rci_nef.calc_RCI(path_to_shifts,output_dir+'/other_output/',panav=args.reref,quiet=args.quiet)
 
@@ -90,9 +98,6 @@ def main():
         except:
             pass
 
-    #    json.dump(chain_output_rigidity, open("chain_output_rigidity.tmp",'w'))
-    #json.dump(chain_output_rci, open("chain_output_rci.tmp",'w'))
-
     decomps = glob.glob(output_dir+'/other_output/FIRST/*.decomp')
 
     check_quiet_print(args.quiet,'computing ANSURR scores')
@@ -112,6 +117,7 @@ def main():
     for line in open(output_dir+'/ANSURR_output/scores.out','r'):
         check_quiet_print(args.quiet," -> "+line.strip())
 
+    check_quiet_print(args.quiet,"\n")
     sys.exit(0)
 
       
